@@ -6,8 +6,8 @@
 #' An R package \bold{crossnma} for performing (network) meta-analysis
 #' and (network) meta-regression (allows including up to 3 covariates)
 #' of individual participant data and aggregate data or combination of
-#' both. Each format can come from randomized controlled trials or
-#' non-randomized studies. Estimates are generated in a Bayesian
+#' both (Hamza et al., 2024). Each format can come from randomized controlled
+#' trials or non-randomized studies. Estimates are generated in a Bayesian
 #' framework using JAGS. The implemented models are described by Hamza
 #' et al. (2023).
 #'
@@ -34,18 +34,18 @@
 #' \itemize{
 #' \item To have a list of all R functions available in
 #'   \bold{crossnma} type \code{help(package = "crossnma")}
-#' \item The R command \code{citation("crossnma")} shows how to cite
-#'   \bold{crossnma} in publications.
+#' \item Hamza et al. (2024) is the preferred citation in publications
+#'   for \bold{crossnma}. Type \code{citation("crossnma")} for a BibTeX entry of
+#'   this publication.
 #' \item To report problems and bugs send an email to
-#'   \email{tasnim.hamza@@ispm.unibe.ch}
+#'   \email{hamza.a.tasnim@@gmail.com}
 #' \item The development version of \bold{crossnma} is available on
 #'   GitHub \url{https://github.com/htx-r/crossnma}.
 #'}
+#'
 #' @name crossnma-package
 #'
-#' @docType package
-#'
-#' @author Tasnim Hamza \email{tasnim.hamza@@ispm.unibe.ch},
+#' @author Tasnim Hamza \email{hamza.a.tasnim@@gmail.com},
 #' Guido Schwarzer \email{guido.schwarzer@uniklinik-freiburg.de},
 #' Georgia Salanti \email{georgia.salanti@@ispm.unibe.ch}
 #'
@@ -61,7 +61,13 @@
 #' network meta-regression.
 #' \emph{Research Synthesis Methods},
 #' \bold{14}, 283-300
-#' 
+#'
+#' Hamza T, Schwarzer G, Salanti G (2024):
+#' crossnma: An R Package to Synthesize Cross-Design Evidence and Cross-Format
+#' Data Using Network Meta-Analysis and Network Meta-Regression.
+#' \emph{BMC Medical Research Methodology},
+#' \bold{24}, 169.
+#'
 #' Plummer M (2003):
 #' JAGS: A program for analysis of Bayesian graphical models using
 #' Gibbs sampling
@@ -100,12 +106,12 @@
 #' @importFrom rlang quo
 #' @importFrom stats start end qf sd var update window
 #' @importFrom utils packageDescription combn
-#' @importFrom meta gs
-#' @importFrom netmeta pairwise netmeta netgraph heatplot
-#'   netconnection
+#' @importFrom meta gs pairwise
+#' @importFrom netmeta netmeta netgraph heatplot netconnection
 #' @importFrom rjags jags.model coda.samples
 #' @importFrom coda as.mcmc.list effectiveSize nchain niter nvar
 #'   traceplot varnames
 
+"_PACKAGE"
 
 NULL
